<?php
/**
 * This file belongs to the YIT Plugin Framework.
 *
 * This source file is subject to the GNU GENERAL PUBLIC LICENSE (GPL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.gnu.org/licenses/gpl-3.0.txt
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( ! class_exists( 'YWSN_Unifonic' ) ) {

	/**
	 * Implements Unifonic API for YWSN plugin
	 *
	 * @class   YWSN_Unifonic
	 * @package Yithemes
	 * @since   1.0.0
	 * @author  Your Inspiration Themes
	 *
	 */
	class YWSN_Unifonic extends YWSN_SMS_Gateway {

		/** @var string unifonic user */
		private $_unifonic_user;

		/** @var string unifonic pass */
		private $_unifonic_pass;

		/**
		 * Constructor
		 *
		 * @since   1.0.0
		 * @return  void
		 * @author  Alberto Ruggiero
		 */
		public function __construct() {

			$this->_unifonic_user = get_option( 'ywsn_unifonic_user' );
			$this->_unifonic_pass = get_option( 'ywsn_unifonic_pass' );

			parent::__construct();

		}

		/**
		 * Send SMS
		 *
		 * @since   1.0.0
		 *
		 * @param   $to_phone     string
		 * @param   $message      string
		 * @param   $country_code string
		 *
		 * @return  void
		 * @throws  Exception for WP HTTP API error, no response, HTTP status code is not 201 or if HTTP status code not set
		 * @author  Alberto Ruggiero
		 */
		public function send( $to_phone, $message, $country_code ) {

			$charset = apply_filters( 'ywsn_additional_charsets', get_option( 'ywsn_active_charsets', array() ) );

			if ( '' != $this->_from_asid ) {

				$from = $this->_from_asid;

			} else {

				$from = ( '+' != substr( $this->_from_number, 0, 1 ) ? '+' . $this->_from_number : $this->_from_number );

			}
			$args = array(
				'userid'   => $this->_unifonic_user,
				'password' => $this->_unifonic_pass,
				'to'       => $to_phone,
				'msg'      => $message,
				'sender'   => $from,
			);

			if ( ! empty( $charset ) ) {
				$args['encoding'] = 'UTF8';
			}

			$query_args = http_build_query( $args );

			$wp_remote_http_args = array(
				'method' => 'POST',
				'body'   => $query_args,
				'header' => "Content-type: application/x-www-form-urlencoded\r\n" .
				            "Content-Length: " . strlen( $query_args ) . "\r\n"
			);

			$endpoint = 'https://api.unifonic.com/wrapper/sendSMS.php';

			// perform HTTP request with endpoint / args
			$response = wp_safe_remote_request( esc_url_raw( $endpoint ), $wp_remote_http_args );

			// WP HTTP API error like network timeout, etc
			if ( is_wp_error( $response ) ) {

				throw new Exception( $response->get_error_message() );

			}

			$this->_log[] = $response;

			// Check for proper response / body
			if ( ! isset( $response['body'] ) ) {

				throw new Exception( __( 'No answer', 'yith-woocommerce-sms-notifications' ) );

			}

			if ( strpos( $response['body'], 'Error : 0' ) === false ) {

				throw new Exception( sprintf( __( 'An error has occurred: %s', 'yith-woocommerce-sms-notifications' ), $response['body'] ) );

			}

			return;

		}

	}

}